# Alibi-Explain runtime for MLServer

This package provides a MLServer runtime compatible with Alibi-Explain.

## Usage

You can install the runtime, alongside `mlserver`, as:

```bash
pip install mlserver mlserver-alibi-explain
```
